<%--
  - Author: hanno
  - Version: 1.0
  - Copyright (C) 2012 TopCoder Inc., All Rights Reserved.
  -
  - Description: This page renders the Bing Map with the FARS accidents data
  - searching functionality integrated.
  - 
  - It relies on Bing Maps AJAX Control V7.0 to present the Bing Map.
  - The JS code to create the map and search FARS data are encapsulated in
  - FARSBingMap.js.
  -
  - If the map page is viewed before the FARS data upload completed, then this
  - page disables the search functionalities and informs users that the
  - accidents data are not available. Whether the FARS accidents data are
  - available can be told by examining whether the ${dataSource.dataSourceUrl}
  - is available.
--%>
<%@ page language="java" contentType="text/html; charset=ISO-8859-1" pageEncoding="UTF-8"%>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>Bing Map Mashup</title>
<!-- External CSS -->
<jsp:include page="common/commonCSS.jsp" />
<!-- External Javascript -->
<jsp:include page="common/commonJS.jsp" />
<script type="text/javascript" src="http://ecn.dev.virtualearth.net/mapcontrol/mapcontrol.ashx?v=7.0" charset="UTF-8"></script>
<script type="text/javascript" src="js/FARSBingMap.js"></script>
<script>
    // The FARSBingMap object
    var farsBingMap;

    // The function creates FARSBingMap on page load
    $(document).ready(function () {
        // The data source object
        var dataSource = {
            queryKey : '${dataSource.queryKey}',
            dataSourceUrl : '${dataSource.dataSourceUrl}',
            entityTypeName : '${dataSource.entityTypeName}'
        };

        if (!dataSource.dataSourceUrl) {
            $('#bingMapDiv').hide();
            $('.leftColumn').hide()
        } else {
            $('#bingMapDivEmpty').hide();
            farsBingMap = new FARSBingMap(dataSource, 'bingMapDiv');
        }
    });
</script>
</head>
<body>
  <div id="wrapper">
    <div id="header">
      <h1 id="logo">
        <img src="i/logo.png" alt="" />
      </h1>
    </div>
    <!--End header-->
    <div id="content">
      <div class="leftColumn">
        <ul>
          <li><a href="javascript:;" class="expandCollapseBar"><span class="right"><span class="middle">Search</span></span></a>
            <div class="sub hide">
              <p>
                <span class="inputBox"> <span class="right"> <span class="middle"> <input id="addressInput" type="text" value="Search Term" class="hint" />
                  </span>
                </span>
                </span>
              </p>
              <p class="formElement">
                <select id="mileage">
                  <option value="5">5 Miles</option>
                  <option value="10">10 Miles</option>
                  <option value="25">25 Miles</option>
                </select>
              </p>
              <a id='btnSearch' href="javascript:;" class="btn" onclick="farsBingMap.findAddress($.trim($('#addressInput').val()), $('#mileage').val());"><span class="right"><span
                  class="middle"
                >Search</span></span></a>
            </div></li>
          <li class="row2"><a href="javascript:;" class="expandCollapseBar"><span class="right"><span class="middle">Directions</span></span></a>
            <div class="sub hide">
              <p>
                <span class="inputBox"> <span class="right"> <span class="middle"> <input id="rStart" type="text" value="Start" class="hint" />
                  </span>
                </span>
                </span>
              </p>
              <p>
                <span class="inputBox"> <span class="right"> <span class="middle"> <input id="rEnd" type="text" value="End" class="hint" />
                  </span>
                </span>
                </span>
              </p>
              <a id='btnShowRoute' href="javascript:;" class="btn" onclick="farsBingMap.findRoute($.trim($('#rStart').val()), $.trim($('#rEnd').val()));"><span class="right"><span
                  class="middle"
                >Show Route</span></span></a>
            </div></li>
        </ul>
      </div>
      <!--End leftColumn-->
      <div id="bingMap">
        <h2>
          <span>BingMap</span> Fatality Analysis Reporting System
        </h2>
        <div id="bingMapDivEmpty">
          <h3>Sorry, but the FARS Data is not available yet. Please come back later...</h3>
        </div>
        <div id="bingMapDiv" style="position: relative; width: 775px; height: 617px;"></div>
        <div class="accidentInvolvingArea">
          <h3>ACCIDENTS INVOLVING:</h3>
          <ul>
            <li class="first pedestrians">Pedestrians</li>
            <li class="vehicles">Vehicles</li>
            <li class="cyclists">Cyclists</li>
            <li class="drugsAlcohol">Drugs/Alcohol</li>
            <li class="schoolRelated">School-related</li>
          </ul>
          <div class="clear"></div>
        </div>
        <!--End accidentInvolvingArea-->
      </div>
      <!--End bingMap-->
      <div class="clear"></div>
    </div>
    <!--End content-->
    <div id="footer">
      <ul>
        <li class="label">Share / Follow us on</li>
        <li><a href="javascript:;"><img src="i/socialFB.png" alt="" /></a></li>
        <li><a href="javascript:;"><img src="i/socialTwitter.png" alt="" /></a></li>
        <li><a href="javascript:;"><img src="i/socialEmail.png" alt="" /></a></li>
        <li><a href="javascript:;"><img src="i/socialIN.png" alt="" /></a></li>
        <li><a href="javascript:;"><img src="i/socialAdd.png" alt="" /></a></li>
      </ul>
      <p>
        <span>Copyright &copy; 2012 All Rights Reserved.</span> <a href="javascript:;">Terms of Use</a> <a href="javascript:;">Privacy Policy</a>
      </p>
    </div>
    <!--End footer-->
  </div>
  <!--End wrapper-->
</body>
</html>
