/*
 * Copyright (C) 2012 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.bingmap.mashup.controller.fars;

import javax.annotation.PostConstruct;

import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;

import com.topcoder.bingmap.spatial.datasource.BingSpatialConfigurationException;
import com.topcoder.bingmap.spatial.datasource.BingSpatialDataSourceManager;

/**
 * This controller shows the Bing Map with functionalities to search FARS
 * accidents data.
 *
 * <p>
 * <b>Thread Safety:</b> This class is thread safe since it does not modify
 * anything and after Spring injection is done no setters will be called by the
 * framework any more.
 * </p>
 *
 * @author liuliquan, hanno
 * @version 1.0
 */
@Controller
public class FARSBingMapMashupController {
    /**
     * The configured data source manager.
     *
     * This field will be injected by Spring automatically.
     */
    private BingSpatialDataSourceManager dataSourceManager;

    /**
     * Empty constructor for controller class.
     */
    public FARSBingMapMashupController() {
        // empty
    }

    /**
     * Check bean is configured correctly.
     *
     * @throws BingSpatialConfigurationException
     *             if the bean is not configured correctly
     */
    @PostConstruct
    protected void checkInit() {
        if (this.dataSourceManager == null) {
            throw new BingSpatialConfigurationException("dataSourceManager is not set.");
        }
    }

    /**
     * Show the Bing Map view page to search FARS data.
     *
     * @param model
     *            the model for the page
     * @return the Bing Map page view
     */
    @RequestMapping(method = RequestMethod.GET, value = "/farsBingMap")
    public String showBingMap(Model model) {
        model.addAttribute("dataSource", this.dataSourceManager.getDataSource());
        return "farsBingMap";
    }

    /**
     * Setter of dataSourceManager.
     *
     * <p>
     * Called by Spring for injection.
     * </p>
     *
     * @param dataSourceManager
     *            the data source manager
     */
    public void setDataSourceManager(BingSpatialDataSourceManager dataSourceManager) {
        this.dataSourceManager = dataSourceManager;
    }
}
