/*
 * Copyright (C) 2012 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.bingmap.spatial.datasource;

import java.io.InputStream;

/**
 * This interface defines the contract to parse Bing Spatial data file from
 * given input data stream.
 *
 * <p>
 * <b>Thread Safety:</b> Implementations of this interface must be thread safe.
 * </p>
 *
 * @author liuliquan, hanno
 * @version 1.0
 */
public interface BingSpatialDataParser {
    /**
     * Parse given input data stream and produce the formatted result Bing
     * Spatial data.
     *
     * @param data
     *            The input data stream
     * @return The parsed Bing Spatial data
     * @throws IllegalArgumentException
     *             if given data stream is null.
     * @throws BingSpatialDataParsingException
     *             if any error occurs while parsing.
     */
    public BingSpatialData parseData(InputStream data) throws BingSpatialDataParsingException;
}
