/*
 * Copyright (C) 2012 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.bingmap.spatial.datasource;

/**
 * This interface defines the contracts to load data into Bing Spatial data
 * source, check data source status and get the data source.
 *
 * <p>
 * <b>Thread Safety:</b> The ultimate thread safety depends on the thread safety
 * of Bing Spatial DataSource Management API.
 * </p>
 *
 * @author liuliquan, hanno
 * @version 1.0
 */
public interface BingSpatialDataSourceManager {
    /**
     * Create a Bing Spatial DataFlow job to load data into data source.
     *
     * This method creates a new data source if it does not exist, otherwise
     * depending on the given loadType: a) If loadType is COMPLETE, the existing
     * data will be replaced with the newly uploaded data b) If loadType is
     * INCREMENTAL, then if the entity ID of a set of newly uploaded data
     * matches an existing entity ID in the data source, the existing entity
     * data is replaced by the new data. If the new entity ID does not exist, a
     * new entity is created.
     *
     * <p>
     * Note this method returns once the load job is created, but it may not be
     * completed.
     * </p>
     *
     * @param data
     *            The data to be uploaded to Bing Spatial DataSource
     * @param loadType
     *            The load type
     * @throws IllegalArgumentException
     *             if any parameter is null
     * @throws BingSpatialDataSourceManagementException
     *             if any error occurs while loading data.
     */
    public void loadData(BingSpatialData data, BingSpatialDataLoadType loadType)
        throws BingSpatialDataSourceManagementException;

    /**
     * Check the data source status.
     * <p>
     * When the data source load job is completed, it generates an url to query
     * the data source. This url is saved so the front end can use it
     * afterwards.
     * </p>
     *
     * @return The data source status.
     * @throws BingSpatialDataSourceManagementException
     *             If any error occurs while checking the status.
     */
    public BingSpatialDataSourceStatus checkDataSourceStatus() throws BingSpatialDataSourceManagementException;

    /**
     * Gets the Bing Spatial data source.
     *
     * @return the Bing Spatial data source.
     */
    public BingSpatialDataSource getDataSource();
}
