/*
 * Copyright (C) 2012 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.bingmap.spatial.datasource;

import java.util.Date;

/**
 * This class represents the Bing Spatial Data Source status.
 *
 * <p>
 * <b>Thread Safety:</b> This class is mutable and not thread safe.
 * </p>
 *
 * @author liuliquan, hanno
 * @version 1.0
 */
public class BingSpatialDataSourceStatus {
    /**
     * The status of data source. Can be either 'Pending', 'Aborted' or
     * 'Completed'.
     */
    private String status;

    /**
     * The total entity count in data source.
     */
    private int totalEntityCount;

    /**
     * The count of entity processed when uploading to data source.
     */
    private int processedEntityCount;

    /**
     * The count of entity failed when uploading to data source.
     */
    private int failedEntityCount;

    /**
     * The create date.
     */
    private Date createdDate;

    /**
     * The data of upload completed.
     */
    private Date completedDate;

    /**
     * The create date.
     */
    private String createdDateFormatted;

    /**
     * The data of upload completed.
     */
    private String completedDateFormatted;

    /**
     * The message if there is any error.
     */
    private String errorMessage;

    /**
     * Empty constructor.
     */
    public BingSpatialDataSourceStatus() {
        // empty
    }

    /**
     * Returns the status.
     *
     * @return the status
     */
    public String getStatus() {
        return status;
    }

    /**
     * Sets the status.
     *
     * @param status
     *            the new status to set
     */
    public void setStatus(String status) {
        this.status = status;
    }

    /**
     * Returns the totalEntityCount.
     *
     * @return the totalEntityCount
     */
    public int getTotalEntityCount() {
        return totalEntityCount;
    }

    /**
     * Sets the totalEntityCount.
     *
     * @param totalEntityCount
     *            the new totalEntityCount to set
     */
    public void setTotalEntityCount(int totalEntityCount) {
        this.totalEntityCount = totalEntityCount;
    }

    /**
     * Returns the processedEntityCount.
     *
     * @return the processedEntityCount
     */
    public int getProcessedEntityCount() {
        return processedEntityCount;
    }

    /**
     * Sets the processedEntityCount.
     *
     * @param processedEntityCount
     *            the new processedEntityCount to set
     */
    public void setProcessedEntityCount(int processedEntityCount) {
        this.processedEntityCount = processedEntityCount;
    }

    /**
     * Returns the failedEntityCount.
     *
     * @return the failedEntityCount
     */
    public int getFailedEntityCount() {
        return failedEntityCount;
    }

    /**
     * Sets the failedEntityCount.
     *
     * @param failedEntityCount
     *            the new failedEntityCount to set
     */
    public void setFailedEntityCount(int failedEntityCount) {
        this.failedEntityCount = failedEntityCount;
    }

    /**
     * Returns the createdDate.
     *
     * @return the createdDate
     */
    public Date getCreatedDate() {
        return createdDate;
    }

    /**
     * Sets the createdDate.
     *
     * @param createdDate
     *            the new createdDate to set
     */
    public void setCreatedDate(Date createdDate) {
        this.createdDate = createdDate;
    }

    /**
     * Returns the completedDate.
     *
     * @return the completedDate
     */
    public Date getCompletedDate() {
        return completedDate;
    }

    /**
     * Sets the completedDate.
     *
     * @param completedDate
     *            the new completedDate to set
     */
    public void setCompletedDate(Date completedDate) {
        this.completedDate = completedDate;
    }

    /**
     * Returns the errorMessage.
     *
     * @return the errorMessage
     */
    public String getErrorMessage() {
        return errorMessage;
    }

    /**
     * Sets the errorMessage.
     *
     * @param errorMessage
     *            the new errorMessage to set
     */
    public void setErrorMessage(String errorMessage) {
        this.errorMessage = errorMessage;
    }

    /**
     * Returns the createdDateFormatted.
     *
     * @return the createdDateFormatted
     */
    public String getCreatedDateFormatted() {
        return createdDateFormatted;
    }

    /**
     * Sets the createdDateFormatted.
     *
     * @param createdDateFormatted
     *            the new createdDateFormatted to set
     */
    public void setCreatedDateFormatted(String createdDateFormatted) {
        this.createdDateFormatted = createdDateFormatted;
    }

    /**
     * Returns the completedDateFormatted.
     *
     * @return the completedDateFormatted
     */
    public String getCompletedDateFormatted() {
        return completedDateFormatted;
    }

    /**
     * Sets the completedDateFormatted.
     *
     * @param completedDateFormatted
     *            the new completedDateFormatted to set
     */
    public void setCompletedDateFormatted(String completedDateFormatted) {
        this.completedDateFormatted = completedDateFormatted;
    }
}
