/*
 * Copyright (C) 2012 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.bingmap.mashup.controller.fars;

import junit.framework.Assert;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.mockito.Mock;
import org.mockito.Mockito;
import org.mockito.MockitoAnnotations;
import org.springframework.ui.Model;

import com.topcoder.bingmap.spatial.datasource.BingSpatialConfigurationException;
import com.topcoder.bingmap.spatial.datasource.BingSpatialDataSource;
import com.topcoder.bingmap.spatial.datasource.BingSpatialDataSourceManager;

/**
 * Tests for FARSBingMapMashupController class.
 *
 * @author hanno
 * @version 1.0
 */
public class FARSBingMapMashupControllerTest {
    /**
     * Controller to be tested.
     */
    private FARSBingMapMashupController controller;

    /**
     * Data source manager mock.
     */
    @Mock
    private BingSpatialDataSourceManager dsManager;

    /**
     * Data source mock.
     */
    @Mock
    private BingSpatialDataSource dataSource;

    /**
     * Mocked model.
     */
    @Mock
    private Model model;

    /**
     * Test set up.
     */
    @Before
    public void setUp() {
        MockitoAnnotations.initMocks(this);
        this.controller = new FARSBingMapMashupController();
        this.controller.setDataSourceManager(this.dsManager);
        this.controller.checkInit();

        Mockito.when(this.dsManager.getDataSource()).thenReturn(this.dataSource);
    }

    /**
     * Clean up.
     */
    @After
    public void cleanUp() {
        this.controller = null;
        this.dsManager = null;
        this.dataSource = null;
        this.model = null;
    }

    /**
     * showBingMap test.
     */
    @Test
    public void showBingMap() {
        String view = this.controller.showBingMap(this.model);
        Assert.assertEquals("view", "farsBingMap", view);
        Mockito.verify(this.model).addAttribute("dataSource", this.dataSource);
    }

    /**
     * CheckInit without data source manager.
     */
    @Test(expected = BingSpatialConfigurationException.class)
    public void checkInitNullDs() {
        this.controller.setDataSourceManager(null);
        this.controller.checkInit();
    }
}
