/*
 * Copyright (C) 2012 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.bingmap.spatial.datasource;

import junit.framework.Assert;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

/**
 * Unit tests for BingSpatialDataSource class.
 *
 * @author hanno
 * @version 1.0
 */
public class BingSpatialDataSourceTest {
    /**
     * To be tested.
     */
    private BingSpatialDataSource ds;

    /**
     * Test setup.
     */
    @Before
    public void setUp() {
        this.ds = new BingSpatialDataSource();

        this.ds.setDataSourceName("ds_name");
        this.ds.setDataSourceUrlFile("url file");
        this.ds.setEntityTypeName("entity");
        this.ds.setMasterKey("master");
        this.ds.setQueryKey("query");

        this.ds.checkInit();
    }

    /**
     * Test clean up.
     */
    @After
    public void cleanUp() {
        this.ds = null;
    }

    /**
     * checkInit test.
     *
     * <table border="1">
     * <tr>
     * <th>Input</th>
     * <th>Expected</th>
     * </tr>
     * <tr>
     * <td>invalid configuration</td>
     * <td>BingSpatialConfigurationException</td>
     * </tr>
     * </table>
     */
    @Test(expected = BingSpatialConfigurationException.class)
    public void checkInitEmptyName() {
        this.ds.setDataSourceName("");
        this.ds.checkInit();
    }

    /**
     * checkInit test.
     *
     * <table border="1">
     * <tr>
     * <th>Input</th>
     * <th>Expected</th>
     * </tr>
     * <tr>
     * <td>invalid configuration. name has 51 characters.</td>
     * <td>BingSpatialConfigurationException</td>
     * </tr>
     * </table>
     */
    @Test(expected = BingSpatialConfigurationException.class)
    public void checkInitNameTooLong() {
        this.ds.setDataSourceName("123456789012345678901234567890123456789012345678901");
        this.ds.checkInit();
    }

    /**
     * checkInit test.
     *
     * <table border="1">
     * <tr>
     * <th>Input</th>
     * <th>Expected</th>
     * </tr>
     * <tr>
     * <td>invalid configuration</td>
     * <td>BingSpatialConfigurationException</td>
     * </tr>
     * </table>
     */
    @Test(expected = BingSpatialConfigurationException.class)
    public void checkInitNameInvalidCharacters() {
        this.ds.setDataSourceName("name?");
        this.ds.checkInit();
    }

    /**
     * checkInit test.
     *
     * <table border="1">
     * <tr>
     * <th>Input</th>
     * <th>Expected</th>
     * </tr>
     * <tr>
     * <td>invalid configuration</td>
     * <td>BingSpatialConfigurationException</td>
     * </tr>
     * </table>
     */
    @Test(expected = BingSpatialConfigurationException.class)
    public void checkInitNameNull() {
        this.ds.setDataSourceName(null);
        this.ds.checkInit();
    }

    /**
     * checkInit test.
     *
     * <table border="1">
     * <tr>
     * <th>Input</th>
     * <th>Expected</th>
     * </tr>
     * <tr>
     * <td>valid configuration</td>
     * <td>correct name</td>
     * </tr>
     * </table>
     */
    @Test
    public void checkInit() {
        this.ds.setDataSourceName("Asdf123~`!$^_={}");
        this.ds.checkInit();
        Assert.assertEquals("name", "Asdf123~`!$^_={}", this.ds.getDataSourceName());
    }
}
