/*
 * Copyright (C) 2012 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.bingmap.spatial.datasource;

import java.io.ByteArrayInputStream;
import java.io.InputStream;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

/**
 * Unit tests for BingSpatialData class.
 *
 * @author hanno
 * @version 1.0
 */
public class BingSpatialDataTest {
    /**
     * CSV format.
     */
    private static final String FORMAT = "csv";

    /**
     * text/plain MimeType.
     */
    private static final String MIME = "text/plain";

    /**
     * An input stream.
     */
    private InputStream data;

    /**
     * Set up.
     */
    @Before
    public void setUp() {
        this.data = new ByteArrayInputStream(new byte[0]);
    }

    /**
     * Clean up.
     */
    @After
    public void cleanUp() {
        this.data = null;
    }

    /**
     * Constructor with null data.
     *
     * <table border="1">
     * <tr>
     * <th>Input</th>
     * <th>Expected</th>
     * </tr>
     * <tr>
     * <td>null data stream</td>
     * <td>IllegalArgumentException</td>
     * </tr>
     * </table>
     */
    @Test(expected = IllegalArgumentException.class)
    public void constructorNullData() {
        new BingSpatialData(null, FORMAT, MIME);
    }

    /**
     * Constructor with empty format.
     *
     * <table border="1">
     * <tr>
     * <th>Input</th>
     * <th>Expected</th>
     * </tr>
     * <tr>
     * <td>empty format</td>
     * <td>IllegalArgumentException</td>
     * </tr>
     * </table>
     */
    @Test(expected = IllegalArgumentException.class)
    public void constructorEmptyFormat() {
        new BingSpatialData(this.data, "", MIME);
    }

    /**
     * Constructor with null format.
     *
     * <table border="1">
     * <tr>
     * <th>Input</th>
     * <th>Expected</th>
     * </tr>
     * <tr>
     * <td>null format</td>
     * <td>IllegalArgumentException</td>
     * </tr>
     * </table>
     */
    @Test(expected = IllegalArgumentException.class)
    public void constructorNullFormat() {
        new BingSpatialData(this.data, null, MIME);
    }

    /**
     * Constructor with empty MIME.
     *
     * <table border="1">
     * <tr>
     * <th>Input</th>
     * <th>Expected</th>
     * </tr>
     * <tr>
     * <td>empty MIME</td>
     * <td>IllegalArgumentException</td>
     * </tr>
     * </table>
     */
    @Test(expected = IllegalArgumentException.class)
    public void constructorEmptyMime() {
        new BingSpatialData(this.data, FORMAT, "");
    }

    /**
     * Constructor with null MIME.
     *
     * <table border="1">
     * <tr>
     * <th>Input</th>
     * <th>Expected</th>
     * </tr>
     * <tr>
     * <td>null MIME</td>
     * <td>IllegalArgumentException</td>
     * </tr>
     * </table>
     */
    @Test(expected = IllegalArgumentException.class)
    public void constructorNullMime() {
        new BingSpatialData(this.data, FORMAT, null);
    }
}
