/*
 * Copyright (C) 2012 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.bingmap.spatial.datasource;

import java.io.File;
import java.io.FileInputStream;
import java.util.Properties;

import junit.framework.Assert;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

/**
 * Unit tests for BingSpatialProperties.
 *
 * @author hanno
 * @version 1.0
 */
public class BingSpatialPropertiesTest {
    /**
     * Unit under test.
     */
    private BingSpatialProperties uut;

    /**
     * A data source.
     */
    private BingSpatialDataSource ds;

    /**
     * Properties file.
     */
    private File props;

    /**
     * Test setup.
     *
     * @throws Exception
     *             to JUnit
     */
    @Before
    public void setUp() throws Exception {
        this.ds = new BingSpatialDataSource();
        this.props = File.createTempFile("test", "props");
        this.ds.setDataSourceUrlFile(this.props.getAbsolutePath());
        this.uut = new BingSpatialProperties(this.ds);
    }

    /**
     * Test clean up.
     */
    @After
    public void cleanUp() {
        TestHelper.delete(this.props);
        this.props = null;
        this.ds = null;
        this.uut = null;
    }

    /**
     * Test all setters and getters.
     *
     * @throws Exception
     *             to JUnit
     */
    @Test
    public void setter() throws Exception {
        Assert.assertEquals("url datasource", null, read().getProperty("datasource"));
        Assert.assertEquals("url job", null, read().getProperty("job"));

        this.uut.setDataflowJobUrl("https://spatial.virtualearth.net");

        Assert.assertEquals("url datasource", null, read().getProperty("datasource"));
        Assert.assertEquals("url job", "https://spatial.virtualearth.net", read().getProperty("job"));

        this.uut.setDataSourceUrl("test 2");

        Assert.assertEquals("url datasource", "test 2", read().getProperty("datasource"));
        Assert.assertEquals("url job", "https://spatial.virtualearth.net", read().getProperty("job"));
    }

    /**
     * Load.
     *
     * @return properties
     * @throws Exception
     *             to JUnit
     */
    private Properties read() throws Exception {
        Properties p = new Properties();
        p.load(new FileInputStream(this.props));
        return p;
    }
}
