/*
 * Copyright (C) 2012 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.bingmap.spatial.datasource;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.io.Reader;

import org.apache.commons.io.FileUtils;

/**
 * Test helper.
 *
 * @author hanno
 * @version 1.0
 */
public class TestHelper {
    /**
     * Empty constructor for helper class.
     */
    private TestHelper() {
        // empty
    }

    /**
     * Create a temporary file with given content.
     *
     * @param content
     *            file content
     * @return a temporary file
     * @throws IOException
     *             if an IO error occurs
     */
    public static File createTempFileWithContent(String content) throws IOException {
        File f = File.createTempFile("test", "data");

        OutputStreamWriter w = null;
        try {
            w = new OutputStreamWriter(new FileOutputStream(f));
            w.write(content);
        } finally {
            if (w != null) {
                w.close();
            }
        }

        return f;
    }

    /**
     * Delete the given file or directory.
     *
     * @param f
     *            file or directory.
     */
    public static void delete(File f) {
        FileUtils.deleteQuietly(f);
    }

    /**
     * Create a temporary directory.
     *
     * @param prefix
     *            name prefix
     * @return a temporary directory
     */
    public static File createTempDir(String prefix) {
        File baseDir = FileUtils.getTempDirectory();
        String baseName = prefix + "." + System.currentTimeMillis() + ".";

        for (int counter = 0; counter < 1000; counter++) {
            File tempDir = new File(baseDir, baseName + counter);
            if (tempDir.mkdir()) {
                return tempDir;
            }
        }

        return null; // tests will fail
    }

    /**
     * Read a file from classpath.
     *
     * @param name
     *            file name
     * @return file from classpath
     * @throws Exception
     *             to JUnit
     */
    public static String readFile(String name) throws Exception {
        return readStream(TestHelper.class.getResourceAsStream(name));
    }

    /**
     * Read a stream into a string.
     *
     * @param stream
     *            input stream
     * @return data from stream
     * @throws Exception
     *             to JUnit
     */
    public static String readStream(InputStream stream) throws Exception {
        Reader r = new InputStreamReader(stream);

        StringBuilder b = new StringBuilder();
        int c;
        while ((c = r.read()) != -1) {
            b.append((char) c);
        }

        r.close();
        return b.toString();
    }
}
